<?php
//
// Copyright (c) 2008-2018 Nagios Enterprises, LLC. All rights reserved.
//

require_once(dirname(__FILE__) . '/config.inc.php');
require_once(dirname(__FILE__) . '/includes/auth.inc.php');
require_once(dirname(__FILE__) . '/includes/utils.inc.php');
require_once(dirname(__FILE__) . '/includes/pageparts.inc.php');


// Initialization stuff
pre_init();
init_session();

// grab GET or POST variables and check pre-reqs
grab_request_vars();
check_prereqs();


route_request();


function route_request()
{
    $cmd = grab_request_var('cmd', '');
    $id = intval(grab_request_var('id', 0));
    $auth_key = grab_request_var('auth_key', '');

    if ($cmd == 'getcmdstatus') {

        // Verify that we are doing this during install and not randomly
        if ($_SESSION['install_auth_key'] == $auth_key && !empty($auth_key)) {

            global $db_tables;
            global $sqlquery;

            // Generate SQL query
            $fieldmap = array(
                "command_id" => $db_tables[DB_NAGIOSXI]["commands"] . ".command_id",
                "command" => $db_tables[DB_NAGIOSXI]["commands"] . ".command",
                "status_code" => $db_tables[DB_NAGIOSXI]["commands"] . ".status_code",
                "result_code" => $db_tables[DB_NAGIOSXI]["commands"] . ".result_code"
            );

            $args = array(
                "sql" => $sqlquery['GetCommands'],
                "fieldmap" => $fieldmap,
                "default_order" => "command_id",
                "useropts" => array('command_id' => $id),
                "limitrecords" => false
            );

            // Execute a non-caching query (needed for fastest Ajax results)
            $sql = generate_sql_query(DB_NAGIOSXI, $args);
            if ($rs = exec_sql_query(DB_NAGIOSXI, $sql, true, false)) {
                $data = $rs->GetAssoc();
            }

            if (!empty($data)) {
                print json_encode($data);
                exit();
            }

        }

    }

    if (!install_needed()) {
        header("Location: " . get_base_url());
        exit();
    }

    $pageopt = get_pageopt("");
    switch ($pageopt) {
        case "install":
            do_install();
            break;
        default:
            show_install();
            break;
    }
}


function show_install($error = false, $msg = "")
{
    $url = get_base_url();
    $admin_name = "Nagios Administrator";
    $admin_email = "root@localhost";
    $admin_password = random_string(20, "$#@!.,%^&");
    $https_only = checkbox_binary(grab_request_var("https_only", 0));
    $notify_by_email = checkbox_binary(grab_request_var("notify_by_email", 1));
    $language = grab_request_var("language", "");

    $current_timezone = get_current_timezone();
    if (!empty($cfg_timezone) && $cfg_timezone != $current_timezone) {
        $current_timezone = $cfg_timezone;
    }
    $timezones = get_timezones();

    // Notification defaults
    $enable_notifications = 1;
    $notify_host_recovery = 1;
    $notify_host_down = 1;
    $notify_host_unreachable = 1;
    $notify_host_flapping = 1;
    $notify_host_downtime = 1;
    $notify_host_acknowledgment = 1;
    $notify_service_recovery = 1;
    $notify_service_warning = 1;
    $notify_service_unknown = 1;
    $notify_service_critical = 1;
    $notify_service_flapping = 1;
    $notify_service_downtime = 1;
    $notify_service_acknowledgment = 1;

    // Priority notification defaults
    $notify_host_recovery_priority = 0;
    $notify_host_down_priority = 0;
    $notify_host_unreachable_priority = 0;
    $notify_host_flapping_priority = 0;
    $notify_host_downtime_priority = 0;
    $notify_host_acknowledgment_priority = 0;
    $notify_service_recovery_priority = 0;
    $notify_service_warning_priority = 0;
    $notify_service_unknown_priority = 0;
    $notify_service_critical_priority = 0;
    $notify_service_flapping_priority = 0;
    $notify_service_downtime_priority = 0;
    $notify_service_acknowledgment_priority = 0;

    do_page_start(array("page_title" => _('Install')));
?>

<script type="text/javascript">
$(document).ready(function() {
    $('#mainframe').css('overflow-y', 'scroll');

    // If SSL only selected, update program url
    $('#https-only').click(function() {
        var purl = $("#url").val();
        if ($(this).is(":checked")) {
            $('.ssl-warning').show();
            if (purl.indexOf("https") < 0) {
                var tmpurl = purl.replace("http", "https");
                $("#url").val(tmpurl);
            }
        } else {
            $('.ssl-warning').hide();
            if (window.location.protocol != "https:") {
                var tmpurl = purl.replace("https", "http");
                $("#url").val(tmpurl);
            }
        }
    });

    // Advanced email settings
    $('.email-advaned').click(function() {
        if ($('.email-settings').is(":visible")) {
            $('.email-settings').hide();
        } else {
            $('.email-settings').show();
        }
    });

    // Step procedures

    $('.next-step').click(function() {
        $('.step').hide();
        $('#step-2').show();
        $('.btn-install').attr('disabled', false);
    });

    $('.prev-step').click(function() {
        $('.step').hide();
        $('#step-1').show();
    });

});
</script>

<div class="container install">
    <div class="row">
        <div class="col-sm-12 col-md-10 col-md-offset-1 col-lg-8 col-lg-offset-2 col-xl-6 col-xl-offset-3">

            <h1><?php echo _('Nagios XI Installation'); ?></h1>

            <p><?php echo _("Finalize your Nagios XI installation and step the initial configuration. These settings can be changed later."); ?></p>

            <?php display_message($error, "", $msg); ?>

            <form id="manageOptionsForm" method="post" class="form-horizontal" action="install.php">

                <input type="hidden" name="install" value="1">
                <?php echo get_nagios_session_protector(); ?>

                <div id="step-1" class="step">
                    <div class="section">
                        <h5><?php echo _('General System Settings'); ?></h5>
                        <div class="well">
                            <div class="form-group">
                                <label for="url" class="control-label col-sm-4 col-md-3"><?php echo _('Program URL'); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <input type="text" size="45" name="url" id="url" value="<?php echo encode_form_val($url); ?>" class="form-control">
                                    <span class="help-icon tt-bind" title="<?php echo _('The default URL that is used to access Nagios XI on this server directly from your internal network.'); ?>"><i class="fa fa-question-circle fa-14"></i></span>
                                </div>
                            </div>
                            <div class="form-group">
                                <label for="timezone" class="control-label col-sm-4 col-md-3"><?php echo _("Timezone"); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <select id="timezone" name="timezone" class="form-control">
                                        <?php
                                        $set = false;
                                        foreach ($timezones as $name => $tz) { ?>
                                            <option value="<?php echo $tz; ?>"<?php if ($tz == $current_timezone) { echo "selected"; $set = true; } ?>><?php echo $name; ?></option>
                                        <?php
                                        }

                                        if (!$set) { ?>
                                            <option value="<?php echo $current_timezone; ?>" selected><?php echo $current_timezone; ?></option>
                                        <?php } ?>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label for="language" class="control-label col-sm-4 col-md-3"><?php echo _("Language"); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <select id="language" name="language" class="form-control">
                                        <?php
                                        $languages = get_languages();
                                        foreach ($languages as $lang => $title) { ?>
                                            <option value="<?php echo $lang; ?>" <?php echo is_selected($language, $lang); ?>><?php echo get_language_nicename($title); ?></option>
                                        <?php } ?>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <div class="col-sm-8 col-sm-offset-4 col-md-9 col-md-offset-3">
                                    <div class="checkbox">
                                        <label>
                                            <input type="checkbox" id="https-only" name="https_only" <?php echo is_checked($https_only, 1); ?> value="1">
                                            <?php echo _("Use HTTPS only (all HTTP requests will be redirected to HTTPS)"); ?>
                                        </label>
                                        <span class="help-icon tt-bind" title="<?php echo _('By default, a self-signed SSL certificate has been created for your Nagios XI installation.'); ?>"><i class="fa fa-question-circle fa-14"></i></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="alert alert-warning ssl-warning hide">
                        <?php echo _('You will need to'); ?> <a href="https://support.nagios.com/kb/article/nagios-xi-configuring-ssl-for-nagios-xi-191.html"><?php echo _('install a valid certificate'); ?></a> <?php echo _('or'); ?> <a href="https://support.nagios.com/kb/article/ssl-tls-understanding-certificate-warnings-598.html"><?php echo _('trust the self-signed certificate'); ?></a> <?php echo _('to remove the "insecure connection" browser message'); ?>.
                    </div>
                    <div class="buttons">
                        <button type="button" class="btn btn-sm btn-default next-step"><?php echo _("Next"); ?> <i class="fa fa-chevron-right r"></i></button>
                    </div>
                </div>

                <div id="step-2" class="step hide">
                    <div class="section">
                        <h5><?php echo _('Admin Account Settings'); ?></h5>
                        <div class="well">
                            <div class="form-group">
                                <label for="un" class="control-label col-sm-4 col-md-3"><?php echo _('Username'); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <input type="text" size="30" name="admin_username" id="un" value="nagiosadmin" class="form-control" disabled>
                                </div>
                            </div>
                            <div class="form-group">
                                <label for="pw" class="control-label col-sm-4 col-md-3"><?php echo _('Password'); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <input type="text" size="20" name="admin_password" id="pw" value="<?php echo encode_form_val($admin_password); ?>" class="form-control">
                                </div>
                            </div>
                            <div class="form-group">
                                <label for="fn" class="control-label col-sm-4 col-md-3"><?php echo _('Full Name'); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <input type="text" size="30" name="admin_name" id="fn" value="<?php echo encode_form_val($admin_name); ?>" class="form-control">
                                </div>
                            </div>
                            <div class="form-group">
                                <label for="email" class="control-label col-sm-4 col-md-3"><?php echo _('Email Address'); ?></label>
                                <div class="col-sm-8 col-md-9">
                                    <input type="text" size="40" name="admin_email" id="email" value="<?php echo encode_form_val($admin_email); ?>" class="form-control">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="section">
                        <h5><?php echo _('Admin Notification Settings'); ?></h5>
                        <div class="well">
                            <div class="form-group">
                                <div class="center">
                                    <div class="checkbox">
                                        <label>
                                            <input type="checkbox" name="notify_by_email" value="1" <?php echo is_checked($notify_by_email, 1); ?>>
                                            <?php echo _("Send this account email notifications"); ?>
                                        </label>
                                        <span class="help-icon tt-bind" title="<?php echo _('Notifications are enabled by default for nagiosadmin but you can disable sending anything by unchecking the box'); ?>"><i class="fa fa-question-circle fa-14"></i></span>
                                        <a class="email-advaned" style="margin-left: 40px;"><?php echo _('Advanced email notification settings'); ?></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="well email-settings hide">
                            <table class="table table-condensed table-no-border table-auto-width" style="margin: 0 auto;">
                                <thead>
                                    <tr>
                                        <th></th>
                                        <th><i class="fa fa-envelope-o tt-bind" title="<?php echo _('Send email'); ?>"></i></th>
                                        <th><i class="fa fa-exclamation-triangle tt-bind" title="<?php echo _('Send email high priority'); ?>"></i></th>
                                        <th></th>
                                        <th></th>
                                        <th><i class="fa fa-envelope-o tt-bind" title="<?php echo _('Send email'); ?>"></i></th>
                                        <th><i class="fa fa-exclamation-triangle tt-bind" title="<?php echo _('Send email high priority'); ?>"></i></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <tr>
                                        <td>
                                            <label for="hostAcknowledgeNotificationsCheckBox"><?php echo _('Host Acknowledgment'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="hostAcknowledgeNotificationsCheckBox" name="notify_host_acknowledgment" <?php echo is_checked($notify_host_acknowledgment, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="hostAcknowledgeNotificationsCheckBoxPriority" name="notify_host_acknowledgment_priority" <?php echo is_checked($notify_host_acknowledgment_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                        <td>&nbsp;&nbsp;&nbsp;&nbsp;</td>
                                        <td>
                                            <label for="serviceAcknowledgeNotificationsCheckBox"><?php echo _('Service Acknowledgment'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceAcknowledgeNotificationsCheckBox" name="notify_service_acknowledgment" <?php echo is_checked($notify_service_acknowledgment, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceAcknowledgeNotificationsCheckBoxPriority" name="notify_service_acknowledgment_priority" <?php echo is_checked($notify_service_acknowledgment_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <label for="hostRecoveryNotificationsCheckBox"><?php echo _('Host Recovery'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="hostRecoveryNotificationsCheckBox" name="notify_host_recovery" <?php echo is_checked($notify_host_recovery, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="hostRecoveryNotificationsCheckBoxPriority" name="notify_host_recovery_priority" <?php echo is_checked($notify_host_recovery_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                        <td>&nbsp;&nbsp;&nbsp;&nbsp;</td>
                                        <td>
                                            <label for="serviceRecoveryNotificationsCheckBox"><?php echo _('Service Recovery'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceRecoveryNotificationsCheckBox" name="notify_service_recovery" <?php echo is_checked($notify_service_recovery, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceRecoveryNotificationsCheckBoxPriority" name="notify_service_recovery_priority" <?php echo is_checked($notify_service_recovery_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <label for="hostDownNotificationsCheckBox"><?php echo _('Host Down'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="hostDownNotificationsCheckBox" name="notify_host_down" <?php echo is_checked($notify_host_down, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="hostDownNotificationsCheckBoxPriority" name="notify_host_down_priority" <?php echo is_checked($notify_host_down_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                        <td>&nbsp;&nbsp;&nbsp;&nbsp;</td>
                                        <td>
                                            <label for="serviceWarningNotificationsCheckBox"><?php echo _('Service Warning'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceWarningNotificationsCheckBox" name="notify_service_warning" <?php echo is_checked($notify_service_warning, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceWarningNotificationsCheckBoxPriority" name="notify_service_warning_priority" <?php echo is_checked($notify_service_warning_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <label for="hostUnreachableNotificationsCheckBox"><?php echo _('Host Unreachable'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="hostUnreachableNotificationsCheckBox" name="notify_host_unreachable" <?php echo is_checked($notify_host_unreachable, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="hostUnreachableNotificationsCheckBoxPriority" name="notify_host_unreachable_priority" <?php echo is_checked($notify_host_unreachable_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                        <td></td>
                                        <td>
                                            <label for="serviceUnknownNotificationsCheckBox"><?php echo _('Service Unknown'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceUnknownNotificationsCheckBox" name="notify_service_unknown" <?php echo is_checked($notify_service_unknown, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceUnknownNotificationsCheckBoxPriority" name="notify_service_unknown_priority" <?php echo is_checked($notify_service_unknown_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <label for="hostFlappingNotificationsCheckBox"><?php echo _('Host Flapping'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="hostFlappingNotificationsCheckBox" name="notify_host_flapping" <?php echo is_checked($notify_host_flapping, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="hostFlappingNotificationsCheckBoxPriority" name="notify_host_flapping_priority" <?php echo is_checked($notify_host_flapping_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                        <td></td>
                                        <td>
                                            <label for="serviceCriticalNotificationsCheckBox"><?php echo _('Service Critical'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceCriticalNotificationsCheckBox" name="notify_service_critical" <?php echo is_checked($notify_service_critical, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceCriticalNotificationsCheckBoxPriority" name="notify_service_critical_priority" <?php echo is_checked($notify_service_critical_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <label for="hostDowntimeNotificationsCheckBox"><?php echo _('Host Downtime'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="hostDowntimeNotificationsCheckBox" name="notify_host_downtime" <?php echo is_checked($notify_host_downtime, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="hostDowntimeNotificationsCheckBoxPriority" name="notify_host_downtime_priority" <?php echo is_checked($notify_host_downtime_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                        <td></td>
                                        <td>
                                            <label for="serviceFlappingNotificationsCheckBox"><?php echo _('Service Flapping'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceFlappingNotificationsCheckBox" name="notify_service_flapping" <?php echo is_checked($notify_service_flapping, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceFlappingNotificationsCheckBoxPriority" name="notify_service_flapping_priority" <?php echo is_checked($notify_service_flapping_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                    <tr>
                                        <td></td>
                                        <td></td>
                                        <td></td>
                                        <td></td>
                                        <td>
                                            <label for="serviceDowntimeNotificationsCheckBox"><?php echo _('Service Downtime'); ?>:</label>
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox regular" id="serviceDowntimeNotificationsCheckBox" name="notify_service_downtime" <?php echo is_checked($notify_service_downtime, 1); ?> title="<?php echo _('Send email'); ?>">
                                        </td>
                                        <td>
                                            <input type="checkbox" class="checkbox priority" id="serviceDowntimeNotificationsCheckBoxPriority" name="notify_service_downtime_priority" <?php echo is_checked($notify_service_downtime_priority, 1); ?> title="<?php echo _('Send email high priority'); ?>">
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                        <div class="buttons">
                            <button type="button" class="btn btn-sm btn-default prev-step"><i class="fa fa-chevron-left l"></i> <?php echo _("Back"); ?></button>
                            <button type="submit" disabled class="btn btn-sm btn-primary btn-install"><i class="fa fa-check l"></i> <?php echo _("Finish Install"); ?></button>
                        </div>
                    </div>
                </div>

            </form>

        </div>
    </div>
</div>

    <?php
    do_page_end();
    exit();
}


function do_install()
{
    global $cfg;

    // check session
    check_nagios_session_protector();

    // get values
    $url = grab_request_var("url", "");
    $admin_name = grab_request_var("admin_name", "");
    $admin_email = grab_request_var("admin_email", "");
    $admin_password = trim(grab_request_var("admin_password", ""));
    $https_only = checkbox_binary(grab_request_var("https_only", 0));
    $notify_by_email = checkbox_binary(grab_request_var("notify_by_email", 0));
    $new_timezone = grab_request_var("timezone", "");
    $language = grab_request_var("language", "");

    // Defaults
    $enable_notifications = "";
    $notify_host_recovery = "";
    $notify_host_down = "";
    $notify_host_unreachable = "";
    $notify_host_flapping = "";
    $notify_host_downtime = "";
    $notify_host_acknowledgment = "";
    $notify_service_recovery = "";
    $notify_service_warning = "";
    $notify_service_unknown = "";
    $notify_service_critical = "";
    $notify_service_flapping = "";
    $notify_service_downtime = "";
    $notify_service_acknowledgment = "";

    // Get email notification settings
    $notify_host_recovery = checkbox_binary(grab_request_var("notify_host_recovery", $notify_host_recovery));
    $notify_host_down = checkbox_binary(grab_request_var("notify_host_down", $notify_host_down));
    $notify_host_unreachable = checkbox_binary(grab_request_var("notify_host_unreachable", $notify_host_unreachable));
    $notify_host_flapping = checkbox_binary(grab_request_var("notify_host_flapping", $notify_host_flapping));
    $notify_host_downtime = checkbox_binary(grab_request_var("notify_host_downtime", $notify_host_downtime));
    $notify_host_acknowledgment = checkbox_binary(grab_request_var("notify_host_acknowledgment", $notify_host_acknowledgment));
    $notify_service_recovery = checkbox_binary(grab_request_var("notify_service_recovery", $notify_service_recovery));
    $notify_service_warning = checkbox_binary(grab_request_var("notify_service_warning", $notify_service_warning));
    $notify_service_unknown = checkbox_binary(grab_request_var("notify_service_unknown", $notify_service_unknown));
    $notify_service_critical = checkbox_binary(grab_request_var("notify_service_critical", $notify_service_critical));
    $notify_service_flapping = checkbox_binary(grab_request_var("notify_service_flapping", $notify_service_flapping));
    $notify_service_downtime = checkbox_binary(grab_request_var("notify_service_downtime", $notify_service_downtime));
    $notify_service_acknowledgment = checkbox_binary(grab_request_var("notify_service_acknowledgment", $notify_service_acknowledgment));
    
    // Get email priority settings
    $notify_host_recovery_priority = checkbox_binary(grab_request_var("notify_host_recovery_priority", ''));
    $notify_host_down_priority = checkbox_binary(grab_request_var("notify_host_down_priority", ''));
    $notify_host_unreachable_priority = checkbox_binary(grab_request_var("notify_host_unreachable_priority", ''));
    $notify_host_flapping_priority = checkbox_binary(grab_request_var("notify_host_flapping_priority", ''));
    $notify_host_downtime_priority = checkbox_binary(grab_request_var("notify_host_downtime_priority", ''));
    $notify_host_acknowledgment_priority = checkbox_binary(grab_request_var("notify_host_acknowledgment_priority", ''));
    $notify_service_recovery_priority = checkbox_binary(grab_request_var("notify_service_recovery_priority", ''));
    $notify_service_warning_priority = checkbox_binary(grab_request_var("notify_service_warning_priority", ''));
    $notify_service_unknown_priority = checkbox_binary(grab_request_var("notify_service_unknown_priority", ''));
    $notify_service_critical_priority = checkbox_binary(grab_request_var("notify_service_critical_priority", ''));
    $notify_service_flapping_priority = checkbox_binary(grab_request_var("notify_service_flapping_priority", ''));
    $notify_service_downtime_priority = checkbox_binary(grab_request_var("notify_service_downtime_priority", ''));
    $notify_service_acknowledgment_priority = checkbox_binary(grab_request_var("notify_service_acknowledgment_priority", ''));

    // Check for errors
    $errors = 0;
    $errmsg = array();
    if (have_value($url) == false)
        $errmsg[$errors++] = _("URL is blank.");
    else if (!valid_url($url))
        $errmsg[$errors++] = _("Invalid URL.");
    if (have_value($admin_name) == false)
        $errmsg[$errors++] = _("Name is blank.");
    if (have_value($admin_email) == false)
        $errmsg[$errors++] = _("Email address is blank.");
    else if (!valid_email($admin_email))
        $errmsg[$errors++] = _("Email address is invalid.");
    if (have_value($admin_password) == false)
        $errmsg[$errors++] = _("Password is blank.");
    if (!is_valid_timezone($new_timezone))
        $errmsg[$errors++] = _("Not a valid timezone.");

    $uid = get_user_id("nagiosadmin");
    if ($uid <= 0)
        $errmsg[$errors++] = "Unable to get user id for admin account.";

    // Handle errors
    if ($errors > 0) {
        show_install(true, $errmsg);
    }

    // Set global system options
    set_option("url", $url);

    // Modify the admin account
    change_user_attr($uid, "email", $admin_email);
    change_user_attr($uid, "name", $admin_name);
    change_user_attr($uid, "password", hash_password($admin_password));
    change_user_attr($uid, "backend_ticket", random_string(32));
    change_user_attr($uid, "api_key", random_string(64));

    // Do user password change callback
    do_user_password_change_callback($uid, $admin_password);

    // Config manager (naigosql) admin settings
    nagiosql_update_user_password("nagiosadmin", $admin_password);
    update_nagioscore_contact("nagiosadmin", array('email' => $admin_email), false);

    // Random PNP / nagios core backend password (used for performance graphs)
    $nagioscore_backend_password = random_string(6);
    $pnp_username = get_component_credential("pnp", "username");
    set_component_credential("pnp", "password", $nagioscore_backend_password);
    $args = array(
        "username" => $pnp_username,
        "password" => $nagioscore_backend_password
    );
    submit_command(COMMAND_NAGIOSXI_SET_HTACCESS, serialize($args));

    // Clear license acceptance for nagiosadmin
    set_user_meta($uid, "license_version", -1, false);
    set_user_meta($uid, "auth_type", "local");

    // Clear inital task settings
    set_option("system_settings_configured", 0);
    set_option("security_credentials_updated", 0);
    set_option("mail_settings_configured", 0);

    // Set language
    if (!empty($language)) {
        set_option("default_language", $language);
        set_language($language);
        $_SESSION["language"] = $language;
    }

    // Set installation flags
    set_db_version();
    set_install_version();

    // check trial start date
    $ts = get_trial_start();
    // make sure something didn't get whacked with the customer's install
    if ($ts == 0 || $ts > time()) {
        // todo...
    }

    // Start enterprise trial by default
    start_enterprise_trial();

    // Delete force install file if it exists
    if (file_exists("/tmp/nagiosxi.forceinstall"))
        unlink("/tmp/nagiosxi.forceinstall");

    // Turn on automatic update checks
    set_option('auto_update_check', true);

    // Do an update check
    do_update_check(true, true);

    // Set user notification options
    set_user_meta($uid, 'enable_notifications', 1, false);
    set_user_meta($uid, 'notify_by_email', $notify_by_email, false);

    set_user_meta($uid, 'notify_host_recovery', $notify_host_recovery, false);
    set_user_meta($uid, 'notify_host_down', $notify_host_down, false);
    set_user_meta($uid, 'notify_host_unreachable', $notify_host_unreachable, false);
    set_user_meta($uid, 'notify_host_flapping', $notify_host_flapping, false);
    set_user_meta($uid, 'notify_host_downtime', $notify_host_downtime, false);
    set_user_meta($uid, 'notify_host_acknowledgment', $notify_host_acknowledgment, false);
    set_user_meta($uid, 'notify_service_recovery', $notify_service_recovery, false);
    set_user_meta($uid, 'notify_service_warning', $notify_service_warning, false);
    set_user_meta($uid, 'notify_service_unknown', $notify_service_unknown, false);
    set_user_meta($uid, 'notify_service_critical', $notify_service_critical, false);
    set_user_meta($uid, 'notify_service_flapping', $notify_service_flapping, false);
    set_user_meta($uid, 'notify_service_downtime', $notify_service_downtime, false);
    set_user_meta($uid, 'notify_service_acknowledgment', $notify_service_acknowledgment, false);
    
    set_user_meta($uid, 'notify_host_recovery_priority', $notify_host_recovery_priority, false);
    set_user_meta($uid, 'notify_host_down_priority', $notify_host_down_priority, false);
    set_user_meta($uid, 'notify_host_unreachable_priority', $notify_host_unreachable_priority, false);
    set_user_meta($uid, 'notify_host_flapping_priority', $notify_host_flapping_priority, false);
    set_user_meta($uid, 'notify_host_downtime_priority', $notify_host_downtime_priority, false);
    set_user_meta($uid, 'notify_host_acknowledgment_priority', $notify_host_acknowledgment_priority, false);
    set_user_meta($uid, 'notify_service_recovery_priority', $notify_service_recovery_priority, false);
    set_user_meta($uid, 'notify_service_warning_priority', $notify_service_warning_priority, false);
    set_user_meta($uid, 'notify_service_unknown_priority', $notify_service_unknown_priority, false);
    set_user_meta($uid, 'notify_service_critical_priority', $notify_service_critical_priority, false);
    set_user_meta($uid, 'notify_service_flapping_priority', $notify_service_flapping_priority, false);
    set_user_meta($uid, 'notify_service_downtime_priority', $notify_service_downtime_priority, false);
    set_user_meta($uid, 'notify_service_acknowledgment_priority', $notify_service_acknowledgment_priority, false);

    // Generate SSL certificate for the IP address
    $privkey = openssl_pkey_new();
    $dn = array("countryName" => "US",
                "stateOrProvinceName" => "Minnesota",
                "localityName" => "St. Paul",
                "organizationName" => "Nagios Enterprises",
                "organizationalUnitName" => "Development",
                "commonName" => $_SERVER['SERVER_ADDR']);
    $csr = openssl_csr_new($dn, $privkey);
    $cert = openssl_csr_sign($csr, null, $privkey, 3650);

    // Export cert, key, and csr
    $privkey_str = "";
    $cert_str = "";
    $csr_str = "";
    openssl_csr_export($csr, $csr_str);
    openssl_x509_export($cert, $cert_str);
    openssl_pkey_export($privkey, $privkey_str);

    // Store cert, key, and csr in certs directory
    $cert_dir = $cfg['root_dir'] . '/var/certs/';
    file_put_contents($cert_dir.'nagiosxi.key', $privkey_str);
    file_put_contents($cert_dir.'nagiosxi.csr', $csr_str);
    file_put_contents($cert_dir.'nagiosxi.crt', $cert_str);

    // Update the ssl certificate to the current ip address
    $_SESSION['ssl_key'] = $cert_dir.'nagiosxi.key';
    $_SESSION['ssl_cert'] = $cert_dir.'nagiosxi.crt';

    // Update apache configuration to do HTTPS only
    if ($https_only) {
        $_SESSION['set_redirect'] = 1;

        // Update config.inc.php
        $cfile = $cfg['root_dir'] . '/html/config.inc.php';
        $cfgfile = file_get_contents($cfile);
        $cfgfile = str_replace("['use_https'] = false;", "['use_https'] = true;", $cfgfile);
        file_put_contents($cfile, $cfgfile);
    }

    // Get the timezone
    set_option('timezone', $new_timezone);

    // Update the timezone if we need to!
    $current_timezone = get_current_timezone();
    if ($current_timezone != $new_timezone) {
        $_SESSION['timezone'] = $new_timezone;
    }

    // Set session auth key
    $_SESSION['install_auth_key'] = random_string(12);

    show_install_complete();
}


/**
 * Show the final finished install page
 *
 * @param bool   $error
 * @param string $msg
 */
function show_install_complete($error = false, $msg = "")
{
    $admin_password = grab_request_var("admin_password", "");
    $auth_key = grab_array_var($_SESSION, 'install_auth_key', '');
    $url = get_option("url", "login.php");
    $cmds = array();
    
    if (array_key_exists('ssl_key', $_SESSION) && array_key_exists('ssl_cert', $_SESSION)) {
        if (!empty($_SESSION['ssl_key']) && !empty($_SESSION['ssl_cert'])) {
            $data = serialize(array($_SESSION['ssl_key'], $_SESSION['ssl_cert']));
            $cmds[] = submit_command(COMMAND_UPDATE_SSL_CONFIG, $data);
        }
    }

    // Check if we should reset session
    if (array_key_exists('set_redirect', $_SESSION)) {
        if ($_SESSION['set_redirect'] == 1) {
            $cmds[] = submit_command(COMMAND_ENABLE_HTTP_REDIRECT);
        }
    }

    // Check for timezone change
    if (array_key_exists('timezone', $_SESSION)) {
        if (is_valid_timezone($_SESSION['timezone'])) {
            $cmds[] = submit_command(COMMAND_CHANGE_TIMEZONE, $_SESSION['timezone']);
        }
    }

    do_page_start(array("page_title" => _('Installation Complete')));
?>

<script type="text/javascript">
<?php if (count($cmds) > 0) { ?>
var CMD_INTERVAL_ID;
var commands = <?php echo json_encode($cmds); ?>;
var commands_num = <?php echo count($cmds); ?>;
var commands_timeout = 0;

function check_commands_running() {
    commands_timeout += 1;

    $.each(commands, function(id, cmd) {
        var ret = '';
        $.ajax({
            type: "GET",
            async: false,
            url: 'install.php',
            data: { cmd: 'getcmdstatus', id: cmd, auth_key: '<?php echo $auth_key; ?>' },
            success: function(data) {
                ret = data;
            }
        });
        if (ret != '') {
            var data = JSON.parse(ret);
            if (data.status_code == 2) {
                commands.splice(id, 1);
            }
        }
    });

    var per_command = Math.ceil(100 / (commands_num + 1));
    var percent = per_command * (commands_num - commands.length + 1);
    if (percent > 100) {
        percent = 100;
    }

    // Finish the commands
    if (commands.length == 0 || commands_timeout >= 5) {
        $('.progress-bar').width('100%');
        clear_whiteout(600, 1000);
        $('#installing').delay(1000).fadeOut(600);
        $('#finished-install').show();
        clearInterval(CMD_INTERVAL_ID);
    } else {
        $('.progress-bar').width(percent + '%');
    }
}

<?php } ?>
$(document).ready(function() {

    // Auto-highlight everything on click
    $('input').click(function() {
        $(this).select();
    });

    $(window).resize(function() {
        if ($('#installing').is(':visible')) {
            $('#installing').center();
        }
    });

    <?php if (count($cmds) > 0) { ?>
    // Watch the processes that we sent commands in for and set loading...
    whiteout();
    $('#installing').center();
    CMD_INTERVAL_ID = setInterval(check_commands_running, 2000);
    <?php } ?>

});
</script>

<div id="installing" style="z-index: 9001; margin-top: -100px; width: 30%; position: absolute;">
    <h1 style="font-weight: normal;"><i class="fa fa-spin fa-pulse fa-spinner"></i> <?php echo _('Finishing Install'); ?> ...</h1>
    <div class="progress">
        <div class="progress-bar" role="progress-bar" aria-valuenow="60" aria-valuemin="0" aria-valuemax="100" style="width: 0%;">
            <span class="sr-only">0%</span>
        </div>
    </div>
</div>

<div id="finished-install" class="container install"<?php if (count($cmds) > 0) { echo ' style="display: none;"'; } ?>>
    <div class="row">
        <div class="col-sm-12 col-md-10 col-md-offset-1 col-lg-8 col-lg-offset-2 col-xl-6 col-xl-offset-3">

            <h1><?php echo _('Installation Complete'); ?></h1>

            <?php display_message($error, false, $msg); ?>

            <p style="padding: 0; margin: 20px 0;"><?php echo _('Congratulations! You have successfully installed Nagios XI. You may now login to Nagios XI using the following credentials.'); ?></p>

            <div style="margin: 20px 0 40px 0;">
                <div class="input-group" style="width: 240px; margin-bottom: 5px;">
                    <div class="input-group-addon" style="width: 90px;"><?php echo _("Username"); ?></div>
                    <input type="text" value="nagiosadmin" class="form-control" readonly>
                </div>
                <div class="input-group" style="width: 240px;">
                    <div class="input-group-addon" style="width: 90px;"><?php echo _("Password"); ?></div>
                    <input type="text" value="<?php echo $admin_password; ?>" class="form-control" readonly>
                </div>
            </div>

            <p>
                <a href="<?php echo $url; ?>" class="btn btn-sm btn-primary" target="_blank" rel="noreferrer"><b><?php echo _('Login to Nagios XI'); ?></b> <i class="fa fa-chevron-right"></i></a>
            </p>

        </div>
    </div>
</div>

<?php
    do_page_end();
    exit();
}